==> kolourpaint_25.08.1.orig.tar.xz: kolourpaint-25.08.1/README.md <==

http://www.kolourpaint.org/

Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>


For licensing and warranty information, read COPYING.
For known problems with this release of KolourPaint, read BUGS.
For what changes have been made, read NEWS.
For developer information, checkout branches/kolourpaint/control/.
For general information, read this file (README):


What is KolourPaint?
====================

KolourPaint is a free, easy-to-use paint program by KDE.

It aims to be conceptually simple to understand; providing a level of
functionality targeted towards the average user.  It's designed for daily
tasks like:

* Painting - drawing diagrams and "finger painting"
* Image Manipulation - editing screenshots and photos; applying effects
* Icon Editing - drawing clipart and logos with transparency

It's not an unusable and monolithic program where simple tasks like drawing
lines become near impossible.  Nor is it so simple that it lacks essential
features like Undo/Redo.

KolourPaint is opensource software written in C++ using the Qt and KDE
libraries.


Features
========

* Undo/Redo Support (10-500 levels of history depending on memory usage)

* Tools (single key shortcuts available for all tools)
  - Brush, Color Eraser, Color Picker, Connected Lines a.k.a. Polyline
  - Curve, Ellipse, Eraser, Flood Fill, Line, Pen, Polygon, Rectangle
  - Rounded Rectangle, Spraycan, Text, Zoom

* Selections (fully undo- and redo-able)
  - Rectangular, Elliptical, Free-Form shapes
  - Choice between Opaque and Transparent selections
  - Full Clipboard/Edit Menu support
  - Freehand resizeable

* Configurable Color Palette

* Color Similarity means that you can fill regions in dithered images and
  photos

* Transparency
  - Draw transparent icons and logos on a checkerboard background
  - All tools can draw in the "Transparent Color"

* Image Effects
  - Autocrop / Remove Internal Border
  - Balance (Brightness, Contrast, Gamma)
  - Clear, Emboss, Flatten, Flip, Histogram Equalizer
  - Hue, Saturation, Value
  - Invert (with choice of channels)
  - Reduce Colors, Reduce to Grayscale, Resize, Rotate
  - Scale, Set as Image (Crop), Skew, Smooth Scale, Soften & Sharpen

* Close-up Editing
  - Zoom (from 0.01x to 16x)
  - Grid
  - Thumbnail

* File Operations
  - Open/Save in all file formats provided by KImageIO
    (PNG, JPEG, BMP, ICO, PCX, TIFF,...) with preview
  - Print, Print Preview
  - Mail
  - Set as Wallpaper


Updates & More Information
==========================

Visit: http://www.kolourpaint.org/


Support
=======

Visit: http://www.kolourpaint.org/

If you have any questions about compiling, installing or using KolourPaint,
don't be afraid to contact us.  We try to support all versions of
KolourPaint and even issues with 3rd party binary packages.


Feedback
========

Please send bug reports and feature requests to http://bugs.kde.org/.
Don't hesitate to report bugs nor hesitate to send us your wishes -- it
provides valuable feedback that will help to improve future versions of
KolourPaint and you will not receive flames for reporting duplicates.

==> kolourpaint_25.12.0.orig.tar.xz: kolourpaint-25.12.0/README.md <==

https://apps.kde.org/kolourpaint/

Copyright (c) 2003-2007 Clarence Dang <dang@kde.org>


For licensing and warranty information, read COPYING.
For known problems with this release of KolourPaint, read BUGS.
For what changes have been made, read NEWS.
For developer information, checkout branches/kolourpaint/control/.
For general information, read this file (README):


What is KolourPaint?
====================

KolourPaint is a free, easy-to-use paint program by KDE.

It aims to be conceptually simple to understand; providing a level of
functionality targeted towards the average user.  It's designed for daily
tasks like:

* Painting - drawing diagrams and "finger painting"
* Image Manipulation - editing screenshots and photos; applying effects
* Icon Editing - drawing clipart and logos with transparency

It's not an unusable and monolithic program where simple tasks like drawing
lines become near impossible.  Nor is it so simple that it lacks essential
features like Undo/Redo.

KolourPaint is opensource software written in C++ using the Qt and KDE
libraries.


Features
========

* Undo/Redo Support (10-500 levels of history depending on memory usage)

* Tools (single key shortcuts available for all tools)
  - Brush, Color Eraser, Color Picker, Connected Lines a.k.a. Polyline
  - Curve, Ellipse, Eraser, Flood Fill, Line, Pen, Polygon, Rectangle
  - Rounded Rectangle, Spraycan, Text, Zoom

* Selections (fully undo- and redo-able)
  - Rectangular, Elliptical, Free-Form shapes
  - Choice between Opaque and Transparent selections
  - Full Clipboard/Edit Menu support
  - Freehand resizeable

* Configurable Color Palette

* Color Similarity means that you can fill regions in dithered images and
  photos

* Transparency
  - Draw transparent icons and logos on a checkerboard background
  - All tools can draw in the "Transparent Color"

* Image Effects
  - Autocrop / Remove Internal Border
  - Balance (Brightness, Contrast, Gamma)
  - Clear, Emboss, Flatten, Flip, Histogram Equalizer
  - Hue, Saturation, Value
  - Invert (with choice of channels)
  - Reduce Colors, Reduce to Grayscale, Resize, Rotate
  - Scale, Set as Image (Crop), Skew, Smooth Scale, Soften & Sharpen

* Close-up Editing
  - Zoom (from 0.01x to 16x)
  - Grid
  - Thumbnail

* File Operations
  - Open/Save in all file formats provided by KImageIO
    (PNG, JPEG, BMP, ICO, PCX, TIFF,...) with preview
  - Print, Print Preview
  - Mail
  - Set as Wallpaper


Support
=======

If you have any questions about compiling, installing or using KolourPaint,
don't be afraid to contact us.  We try to support all versions of
KolourPaint and even issues with 3rd party binary packages.


Feedback
========

Please send bug reports and feature requests to https://bugs.kde.org/.
Don't hesitate to report bugs nor hesitate to send us your wishes -- it
provides valuable feedback that will help to improve future versions of
KolourPaint and you will not receive flames for reporting duplicates.
